@@ -14,17 +14,25 @@ namespace Microsoft.Management.UI.Internal
     /// The generic parameter.
     /// </typeparam>
     [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.MSInternal", "CA903:InternalNamespaceShouldNotContainPublicTypes")]
-    [Serializable]
     public class IsGreaterThanFilterRule<T> : SingleValueComparableValueFilterRule<T> where T : IComparable
     {
         /// <summary>
-        /// Initializes a new instance of the IsGreaterThanFilterRule class.
+        /// Initializes a new instance of the <see cref="IsGreaterThanFilterRule{T}"/> class.
         /// </summary>
         public IsGreaterThanFilterRule()
         {
             this.DisplayName = UICultureResources.FilterRule_GreaterThanOrEqual;
         }
 
+        /// <summary>
+        /// Initializes a new instance of the <see cref="IsGreaterThanFilterRule{T}"/> class.
+        /// </summary>
+        /// <param name="source">The source to initialize from.</param>
+        public IsGreaterThanFilterRule(IsGreaterThanFilterRule<T> source)
+            : base(source)
+        {
+        }
+
         /// <summary>
         /// Determines if item is greater than Value.
         /// </summary>
