@@ -10,17 +10,25 @@ namespace Microsoft.Management.UI.Internal
     /// is empty or not.
     /// </summary>
     [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.MSInternal", "CA903:InternalNamespaceShouldNotContainPublicTypes")]
-    [Serializable]
     public class IsNotEmptyFilterRule : IsEmptyFilterRule
     {
         /// <summary>
-        /// Initializes a new instance of the IsNotEmptyFilterRule class.
+        /// Initializes a new instance of the <see cref="IsNotEmptyFilterRule"/> class.
         /// </summary>
         public IsNotEmptyFilterRule()
         {
             this.DisplayName = UICultureResources.FilterRule_IsNotEmpty;
         }
 
+        /// <summary>
+        /// Initializes a new instance of the <see cref="IsNotEmptyFilterRule"/> class.
+        /// </summary>
+        /// <param name="source">The source to initialize from.</param>
+        public IsNotEmptyFilterRule(IsNotEmptyFilterRule source)
+            : base(source)
+        {
+        }
+
         /// <summary>
         /// Gets a values indicating whether the supplied item is not empty.
         /// </summary>
