@@ -10,11 +10,10 @@ namespace Microsoft.Management.UI.Internal
     /// check if it is does not contain the rule's value within it.
     /// </summary>
     [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.MSInternal", "CA903:InternalNamespaceShouldNotContainPublicTypes")]
-    [Serializable]
     public class TextDoesNotContainFilterRule : TextContainsFilterRule
     {
         /// <summary>
-        /// Initializes a new instance of the TextDoesNotContainFilterRule class.
+        /// Initializes a new instance of the <see cref="TextDoesNotContainFilterRule"/> class.
         /// </summary>
         public TextDoesNotContainFilterRule()
         {
@@ -22,6 +21,15 @@ namespace Microsoft.Management.UI.Internal
             this.DefaultNullValueEvaluation = true;
         }
 
+        /// <summary>
+        /// Initializes a new instance of the <see cref="TextDoesNotContainFilterRule"/> class.
+        /// </summary>
+        /// <param name="source">The source to initialize from.</param>
+        public TextDoesNotContainFilterRule(TextDoesNotContainFilterRule source)
+            : base(source)
+        {
+        }
+
         /// <summary>
         /// Determines if Value is not contained within data.
         /// </summary>
