@@ -11,19 +11,27 @@ namespace Microsoft.Management.UI.Internal
     /// check if it is equal to the rule's value.
     /// </summary>
     [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.MSInternal", "CA903:InternalNamespaceShouldNotContainPublicTypes")]
-    [Serializable]
     public class TextEqualsFilterRule : TextFilterRule
     {
         private static readonly string TextEqualsCharactersRegexPattern = "^{0}$";
 
         /// <summary>
-        /// Initializes a new instance of the TextEqualsFilterRule class.
+        /// Initializes a new instance of the <see cref="TextEqualsFilterRule"/> class.
         /// </summary>
         public TextEqualsFilterRule()
         {
             this.DisplayName = UICultureResources.FilterRule_Equals;
         }
 
+        /// <summary>
+        /// Initializes a new instance of the <see cref="TextEqualsFilterRule"/> class.
+        /// </summary>
+        /// <param name="source">The source to initialize from.</param>
+        public TextEqualsFilterRule(TextEqualsFilterRule source)
+            : base(source)
+        {
+        }
+
         /// <summary>
         /// Determines if data is equal to Value.
         /// </summary>
